Documentation
¶
Index ¶
- func BuildFromDirectory(directoryPath string, imageRepository string, contextLogger *log.Entry) (string, error)
- func BuildFromTar(tarPath string, imageRepository string, contextLogger *log.Entry) (string, error)
- func EvaluateURL(url string, branch string) string
- func ExtractRepository(url string, destination string) error
- func Ping() (string, error)
- func PushImage(imageRepository string) error
- func ReadURL(url string) (*tar.Reader, error)
- func Version() (string, error)
- type MessageStream
- type Specification
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func BuildFromDirectory ¶
func BuildFromDirectory(directoryPath string, imageRepository string, contextLogger *log.Entry) (string, error)
BuildFromDirectory send a build request to the docker daemon by sending a tar built with the given directory.
func BuildFromTar ¶
BuildFromTar send a build request to the docker daemon by sending the given tar.
func EvaluateURL ¶
EvaluateURL evaluates github archive download url
func ExtractRepository ¶
ExtractRepository from an url hosting a tar.gz of this repository with an added root directory that will be flatten
Types ¶
type MessageStream ¶
type MessageStream struct {
Error string `json:"error"`
ErrorDetail struct {
Message string `json:"message"`
} `json:"errorDetail"`
ID string `json:"id"`
Progress string `json:"progress"`
ProgressDetail struct {
Current int `json:"current"`
Total int `json:"total"`
} `json:"progressDetail"`
Status string `json:"status"`
Stream string `json:"stream"`
}
MessageStream is a JSON struct to be used to parse incomming message from the Doceker daemon
type Specification ¶
type Specification struct {
Port string `default:"3000"`
LogLevel string `envconfig:"log_level" default:"debug"`
WorkingDirectory string `envconfig:"working_directory"`
RegistryURL string `envconfig:"registry_url"`
RegistryUsername string `envconfig:"registry_username"`
RegistryPassword string `envconfig:"registry_password"`
RegistryEmail string `envconfig:"registry_email"`
APIKey string `envconfig:"api_key"`
GitUsername string `envconfig:"git_username"`
GitPassword string `envconfig:"git_password"`
BitbucketRepositories string `envconfig:"bitbucket_repositories"`
}
Specification to hold the configuration of the application
var ( // Config make things easier but is bad Config *Specification // UnleashVersion UnleashVersion = "0.1.0" )
func ParseConfiguration ¶
func ParseConfiguration() (Specification, error)
ParseConfiguration will parse the configuration of Unleash based on environment variables
func (*Specification) Describe ¶
func (specification *Specification) Describe()
Describe will log all variables parsed with envconfig